# Generated by roxygen2: do not edit by hand

export(analyse_trend)
export(calculate_ps)
export(credits)
export(interpollen)
export(iplot_abundance)
export(iplot_pheno)
export(iplot_pollen)
export(iplot_years)
export(ma)
export(plot_heathour)
export(plot_hour)
export(plot_normsummary)
export(plot_ps)
export(plot_monthly_heatmap)
export(plot_summary)
export(plot_trend)
export(pollen_calendar)
export(quality_control)
importFrom(circular,circular)
importFrom(circular,mean.circular)
importFrom(data.table,data.table)
importFrom(dplyr,"%>%")
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,summarise)
importFrom(dplyr,summarise_all)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_area)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,geom_violin)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,position_dodge)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_brewer)
importFrom(ggplot2,scale_fill_discrete)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_fill_gradientn)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_x_date)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,scale_y_date)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,theme_dark)
importFrom(ggplot2,theme_set)
importFrom(ggplot2,ylab)
importFrom(ggvis,"%>%")
importFrom(ggvis,add_axis)
importFrom(ggvis,axis_props)
importFrom(ggvis,ggvis)
importFrom(ggvis,input_checkboxgroup)
importFrom(ggvis,input_slider)
importFrom(ggvis,layer_lines)
importFrom(ggvis,layer_points)
importFrom(ggvis,scale_numeric)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.copy)
importFrom(grDevices,dev.off)
importFrom(grDevices,graphics.off)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,rainbow)
importFrom(grDevices,recordPlot)
importFrom(graphics,abline)
importFrom(graphics,barplot)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(grid,grid.layout)
importFrom(grid,pushViewport)
importFrom(grid,viewport)
importFrom(lubridate,hour)
importFrom(lubridate,is.POSIXt)
importFrom(lubridate,yday)
importFrom(lubridate,year)
importFrom(plotly,ggplotly)
importFrom(plotly,layout)
importFrom(scales,date_format)
importFrom(scales,pretty_breaks)
importFrom(stats,SSlogis)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,cor.test)
importFrom(stats,getInitial)
importFrom(stats,lm)
importFrom(stats,na.omit)
importFrom(stats,nls)
importFrom(stats,pf)
importFrom(stats,predict)
importFrom(stats,predict.lm)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,smooth.spline)
importFrom(stats,stl)
importFrom(stats,ts)
importFrom(stats,window)
importFrom(tidyr,"%>%")
importFrom(tidyr,gather)
importFrom(tidyr,spread)
importFrom(utils,data)
importFrom(utils,globalVariables)
importFrom(utils,head)
importFrom(writexl,write_xlsx)
importFrom(zoo,na.approx)
