#' A view of the creators
#'
#' Credits
#'
#' @export
credits <- function() {
  print("")
  print("                     .vu5SdXUi                                                                      ")
  print("                   JBQgBBBBBQBQB:           .ZI       :7            UD.                             ")
  print("      BBBi       .QQvQB57.   .7SBB          IQB       BQB           BQu                             ")
  print("     uQBBB       gb BI  MZdBBMP5 Bg         7BB       rI.           QBr                             ")
  print("     QBYQB:    iER5QI  iBIBLsqbBE B rZBQQr  rQQ:DQg.  LI:  .PQBQK   BQr  .EQBQ5   .IBQqSdvMP   uB1  ")
  print("    rBE 5Bd   KBQBbRq  rQgM  iPgQ IEZL:i2Bs iBZBPBBB  QBj :BdLrsQB  RBi rBXvrUBB .BB71BBKiBBi  BQY  ")
  print("    dBi .gB. .BE:dXUB. :BugMEggQ :DI .:: 7B :MQ   gQ7 EQ7 R7 .. .Qi DQ: Q: .: :B.:BX  bB  KQZ rBQ   ")
  print("   :dP7rrKb5 rdKJUIDDM.ig1gjqBQ.s7i7.v7Yi.Q .Dd   XgL 5Rr P ivrs.Sv KR: S r77v gi XdLsDE  .gE:sQ7   ")
  print("   1PI2XIUId .bK.  :MQBQPXBiBRdB. i5.:7i.rQ :SP   SEr 5b7 E:.r7:.E: KEi Z.:77..g..X1r7:    UKI1Z    ")
  print("  :qD:    XKJ 2Ks:..Y.:qQDQ2:PQBQ  bji::rRi iqbqi7IM  2dL rdii:iUE  IZr LPii:iXK iULrr:r.  .IvUu    ")
  print("  r1J     7sU  ijU5u7  :BQK   BgBv  7j1Ju.  :u7:Iuj   L1i  :uYuu7   JU:  :uY1Jr  .vu::jJE   vrq     ")
  print("                                                                                 j7i  .7K   :7J     ")
  print("                                                                                 :ririrr   :7Y.     ")
  print("")
  print("")
  print("")
  print("The creators:")
  print("")
  print(":.:::::.:::::.:::::...............:.:...::i:iiiiiii:iiiiiiri")
  print(".:.:.:::.:.:.:.:....::..:iiPXKL1KMRRDg5v::.::i:i:iii:iiiiiii")
  print(":.:.:.:.:.:.:....isXMQRPBBBBBQBQBQBQBQBQQqr::.::iiiii:iii:ii")
  print("...:.:.:.:...:.ijXdQgRRQgQMQgQQQgQRQMQggRBQBqr.::i:iii:i:i:i")
  print(".............:rUX5PKPPqUK5qgQbbdRDRZZEQggPQBBBP:..i:i:iii:i:")
  print("........... .uEgbE5Sj7i7jSgRPdKK5KIjYu7JKPbQgQBB2i.::i:i:i:i")
  print(".......... .EMgbbIX1LrL5MgqjU77vuiirriivbZggDDQMBQj..:i:i:i:")
  print(".........  EQgdPKPS22EMMX7i7irir:7vsJKPRgEqdKPgRgBQQi.:i:i:i")
  print(". . . . . iQgEdPPJu5KLr.  .......::.::i:rr7712qgQgQBg.::i:i:")
  print(" . . . .  2QPPXRJi:.           . . .   ....ir12PMQMBB5.:::::")
  print(".......  .BDD2MM:     ....:..............:::r712ZMRMBs..::::")
  print(" . . .  .RRMdZQr .i72gMBQBQgUjY7i::::J2bKgEESUL1bBgRBi :::::")
  print("        LBRMQg7 :YUvL777XdEXPUYi.:rLdDQMQMQMBQgSgQggB:..:.::")
  print("        bBDBQ7 ..:rsssdBRPEDSY:  .1QMMDRDEXK5qPEqQgQBi :.:::")
  print("  .   .ZBQBQJ     ..i:rLs7sr. .  .PBQMgPQBQZRdSU2gQRBPi:::::")
  print("      uBBPXb.        ....:.. ... .sD2vriiLjXEMKKjdQQgBQv:i:i")
  print("      72XivEi .             ...  .PKJ:::ii7vsLussSBQg5Lirir:")
  print("       i:.LZ7. ...         ....  :SdUi:::i:i::rJvqQBgv7777ri")
  print("        . ::u:. . .      ..       7SUri:::i:irYuuDQQX7Jvv77r")
  print("            7Y.  .   . :ii...    .iJ75Lrirr77J11PBEPrvvv7L77")
  print("          . rvi     . ...  :dPY:rLDggPviii77JuU2QPPsYvYLsvLr")
  print("           .7j::.... :irir71KggQQBQBBBDurrrssSUEgILJYjYJYjvv")
  print("            :qv::.::iugQMv72II2LsbQEDDQQBbIUKPdgP7vvuJjLJvsv")
  print("             rDr.i:r5QBqi::i:::i:YXDbEdggQEEdPbgsssuJ1sjLsvs")
  print("              jgr77:Kg7       ..::vJ5Xq5dEEPDEM1Jj2jUJuJuYJL")
  print("               Kg2YYIZ:. ..:YXXZdZ521ISEEgEMMgUU1Uj2j1suJ1LJ")
  print("              .rEMEKSIv7i...r7ssEPKIUYKEMgRMbJUUSUI1UJus1JjY")
  print("    .i72qgQBBB::7PgMZdXPLJY7rvY1ss55U5dMgggQ5ujI1UJUu1j2JUYJ")
  print(".1BBBQBBBQQqsi..i7dQBMMqqXXYIKRPq2PbZEQgQgQRBgqIKPbXIj2jUJ1s")
  print("RBQBRgi.      ....:YXMQQQRDgdMZgDZbgRQQQKZRQMQMQRBQBgqu21Uju")
  print("gBurL        .:.. ..:iJKgQBQBQBRQRQMQgZSSPQgRgRgQgQgQQdJ2U2u")
  print("Dgi2         ..:.....:.rvLvIKbqEdREZPPIKKggQgMgMgQgRgQRMddXX")
  print("MQXj         .....:.:...::iivY25qXq5K5PKEDMgRDMgRgRDQZUsuLsv")
  print(":7rvi.       ........:...::7J55S2KSKSqSPbMSOFIA_&_ABRILgPPI2")
  print("")
  print("---- Jesus Rojo ----")
  print("")
  print("")
  print("")
  print("iiiiiriririririririririi:i:i:i:r:i:ii7r7r77v7v7L7L7L7L7L7L7Y")
  print("iiiiriiiiiiiriririi:i:::7sU1X5qPKsv7iii:i:ir77v7v7v7Lvv7v7L7")
  print("i:i:i:i:i:i:i:...rqgBQBRQdEERMRgMgQQBBBQBQBg7:rr77v7v7v7L7v7")
  print(":i:i:i:i:i:i..iuMBBBdEKUsUuqSbPdqdPgDRgRRBBBRLrrrv7v7v7v7vvL")
  print("::::i:i::::.:SBQBgSvsLYYY7suS2UJj1XKDZRZDZBBBQBJii7rv7v7v7vr")
  print("::::::::::. 2BBBgL:i:i:7ri:..irv7LLJuPdBgddBBBQQviirr7r77vrr")
  print(":::::::::..:2BBEY::.:.:.. ....ii77LvJJXDQDbPQQBBBPr:rr7r7rrr")
  print("::.:::.:.:2XdBRr.:.:::.......::ir7rJsuj5DgDZdBBBQBQqiiirr7r7")
  print(":::.:...iXBBBQj...:::.:.......::i:ii77sY25DMZgBBBBBBRr7r7r7r")
  print(".:.:.:.:rgBBDgi..:.:....   . ..:.::i:rr7rvLPZQMBRBQBQYirr7rr")
  print(":.:....7PDBEdg7.... .       ......::iii:rr7JbgBQQQBBB1ri7r7r")
  print(".......1RRRDQB:. ....:.....::i:i:rvISEZDdPj1IPRBQBQBB1r7r7r7")
  print(".......:RBBMB5:rXPQBBQBgqvrirrYubQBQBBBQQQBQQPKQBQBQBs77v77r")
  print("....... rBQBQijE5IISXQQBQQvi:7uMQBMQQQqEqZdgZg2KBBBBgs7L7v77")
  print(".......  iMQR irXPjSRQMQBZU..:JRBQBQPdQQggBggdPugBBQXLJvL7vr")
  print("........  :BU .rs5iv5SYIYrr: .LBgbI27LIX5gQMX522KBBQUUJ1Ysvv")
  print("......... 2Q2 . .:Lsu1Ivi:i. .7PXUsv11XPZPXjY7JudQBgKUUj1YJ7")
  print("......... .BR........:...:::  iPU2vr:::::::irvLUEBQESXUUJjYs")
  print("... .....   S.... .     :.::  7XPSIi:...:::i77uIQQZXPXX12Jsv")
  print(" . .......  .r....     .::.: .isYIX2i:.::iir72KEMRPdPPSS1UsJ")
  print("........... .Lr::...::rri.    .:i7dP7rri77YY5PMDMKbPEqP5Ij1L")
  print(" . ........  KL7rr:::i:..7i. .:YqRQP777vLI5EdgDBDbPEbdKXU2Js")
  print(". . .......  JgL7vriri:.iIBQPPQBBBBDPUI12SbgQgQQDPEPEqP5511Y")
  print(" . . . .....  DZYLvLvs7vuS5gBBBBQBgDdMMDZQPZgQQRPEPdbdKKUIsj")
  print(". . . . . .   rBZ72XgbX2U2u7juSXgEgZRQBRBgPZBQQdZPEbEPq55uUY")
  print(" . . . . . .   sBP7uJriJUUsujS5PSbEQMMqPZZPQQBEZEZPEPPXX2UJJ")
  print(". . . . . . .   vQdvL...::i::iir7sIIKuUqgRBBBggEgEDbdXK22Jjv")
  print("   . . . . . .   :gQIv:::ii7rv7J1XXZX2qQQBQQggDgEgEDPPSSuUss")
  print("    . . . . . . .  EBbv::ruIPdDbgEDqPXMQBQQEggMDgZgEZqK2Ijuv")
  print("   . . . . . .     :QBdui::vJZDZKKUXPQQBQQDgERDMDgDgPbXSU2sJ")
  print("                 rQqrMBESsjvsIqU1IPPRQBQQDMbEQBggZgEZqq55u1L")
  print("            .7UPDBBv.iKBQMdPbZPPSgMRQBRQZggDKdBBQREDPdXXU2Jj")
  print("     .:rjSgMBBQEgRE..:ivSDQgBQBQQQBQQggDDZgdEPERBBBgESXIX1Us")
  print("rXERRBBBQBggZbKdPQP..::i:irs2qdgEgZgdEdDEgdDdDdEZBBBQgS2j1Ju")
  print("QgMZgdDdEPbPZPEPPgBi.:iiiirrYsX5EdDPdPZdgdDdDEZqXPBQBBBgPuY7")
  print("PdqZPEbbqPSZEgPdKZQD..irir71U5SPPEbdPdbZbDdEPZKXLdQQQBQBQBZX")
  print("bSPbDdPKbIbPgbPXbXQRP .irY2sISPXdPZPZZgdZbEPbSSLS8=DQMQgQMBQ")
  print("")
  print("---- Antonio Picornell ----")
  print("")
  print("")
  print("")
  print("777r7r7r7r77v777Y7IjU7r7BUirL5X1SPD1LiLuJ7L7v7v7Yvv7L7LvY7L7")
  print("r7r7r7r7r7r7r7r7v5PKPP5SEQUY21UUXDdBDgP5X2JLr77LvsvYvsvsvsvY")
  print("7r7r7r7r7r7rrir7SqKKDQBQBQBQBgQQBRQMQQDvIKPUjvY7LvsvsLsvsvYv")
  print("rrrrr7rri777YIs21EZRQQMBQBBBQBQBQBBBQBQQQgPDEgK5JvvsvYvsvYvY")
  print("rrrrrirrYLYuZ2PEDgBBBQBQBgMgRggRBQQBBBBQBbd1I5ZU2Y77LvL7v7v7")
  print("irrrrrirLYJIUPEBQBQZ2Yri....:::rrss5KZDBQBBBgDZguLrLvYvYvLvY")
  print("riririiiv7XI2RBBI:...   . . ..:.::::rr7ruPQQBBBQg7v7LvsvY7L7")
  print("iiii::7QQRgBBDi. . . . . ... ........::iirijDBBBQQL7rv7L7v7v")
  print("i:i:::MQQQBB7  .. .             ......::ii7r75BBBBQ7rr77v777")
  print(":i:i:rrqDBg: ...                 . ..::iirr77vuBQBQM7rr777r7")
  print("::::i:.SBQr ...                 .  .::iirr77LLsSBQBQPrrr7r7r")
  print("::::.::KQE ...                     ..::iirr77uu2DBQBQMLririr")
  print(":.:.:.:SBi ..                         ....:iY1IjgBBBBX7:riri")
  print("......:BQ. ..rIZPMgMP5vi..   .     ..:rJu1UXuU2UbBQBQD:iiiii")
  print("..... iQB. .Y2Yir7uXDQBQBEJiiir:vsdQBQBQBQBBBP5sZBBQBUi:iii:")
  print(".......KBi :rr:i:i:rYPqPKZXLi7L1ZQQBMgqUvJu5XDIjZBQBRJii:i:i")
  print(".....:LJB:..:iUPgqBQBQBQgDK...rZBBBQBQBMMgREEPXuRBBQDirii:i:")
  print(".... .7QQr . :iLL7YjLYjj:...  :EddED2XPQgQQQdSu5QBQdv7rririi")
  print(".....  JBi    ..irv77:.       .vr.::rjqPDggqYrLLBQUr7777vr7r")
  print(" . .    Pr                .   .sv:.    ..::::irvggvJL7rY7vrr")
  print("  . .   ::. .         :....   :72Jv:.   . ..:rsLDq1Ju7s7vrri")
  print("       .ii....   ..r5Q:       .:i.:RPv:i:iirrJUIZgU1J7r7r7ir")
  print("        r:.::...rUgQDr:2U.   .irJ5DDggPYL7Ju22S2D2IUuvLvvrri")
  print("        ri.7v7ruPQE5:.iqQBqIXZQBQBBQ2EgMPKIKPdqPZ52IYjsJvv77")
  print("        rr:7IrudQRgIjYvvXEBBBQBQBQBMgZQQBBRbdZddDUS1Usjvv77r")
  print("        .Si7IrsRBBBBQBKKXPXbgZEDPZgBQBQBBQPPdDKgPX5I1UYY7v77")
  print("         2U:LriJQqi.iSDu:.::irP2PgBBgKKMPrIbRZMZPSXUUJuLL77r")
  print("         .MKUUiLU:     .  ...7LJISuYr77PujPQQQMbXKIIuuLs7vr7")
  print("          :g51JJs.  . . ....:::i7L1sYsX2K5QMQRbXP551Ussvv77r")
  print("            KSJuv:   ::7JqqgZRKbKbUY72qddRQBgKIP55u1LYvv77rr")
  print("           vBZPXIv:     ::vs5Ljr7r:.rUgQBQRRBbX2S22JuLY7vrri")
  print("         .KBBruBQPjr..    .:.:.::i:iIgMBQRPBBQgP2Uj1YsvL77rr")
  print("        JgZgQ .7QQBDur7r::riir7r7sXPBQBRgbQQQgBQQIS21YY77rri")
  print("      .EZS2ZX ...LdBBRPqrjuv7Y1EZQBBBBZZZQBBgRgBQESqIS22JYrr")
  print("  ..i2RqIj1ZD .::.:7PMBQQMBQBQBQBQBgZPDgQQBMRgRgQgXIIuSuI25j")
  print("ii.7Kd22jusDQ....::ir7v5KbbgdgEZPPXPPDgQQBMgDMgMDQX1J2j1YuJu")
  print(":.rXS12uUJu5B:..::ii7r77sjIIS2qSqKPPgDQQBMDEMDMZggZvjsjLL7vv")
  print(".7K5juJ1JUJuM2.:::.:irrvLuuX2KIS5PqDZMARCOKdEgMArCOJvY7v7v7v")
  print("")
  print("---- Jose Oteros ----")
  print("")
  print("")
  print("                     .vu5SdXUi                                                                      ")
  print("                   JBQgBBBBBQBQB:           .ZI       :7            UD.                             ")
  print("      BBBi       .QQvQB57.   .7SBB          IQB       BQB           BQu                             ")
  print("     uQBBB       gb BI  MZdBBMP5 Bg         7BB       rI.           QBr                             ")
  print("     QBYQB:    iER5QI  iBIBLsqbBE B rZBQQr  rQQ:DQg.  LI:  .PQBQK   BQr  .EQBQ5   .IBQqSdvMP   uB1  ")
  print("    rBE 5Bd   KBQBbRq  rQgM  iPgQ IEZL:i2Bs iBZBPBBB  QBj :BdLrsQB  RBi rBXvrUBB .BB71BBKiBBi  BQY  ")
  print("    dBi .gB. .BE:dXUB. :BugMEggQ :DI .:: 7B :MQ   gQ7 EQ7 R7 .. .Qi DQ: Q: .: :B.:BX  bB  KQZ rBQ   ")
  print("   :dP7rrKb5 rdKJUIDDM.ig1gjqBQ.s7i7.v7Yi.Q .Dd   XgL 5Rr P ivrs.Sv KR: S r77v gi XdLsDE  .gE:sQ7   ")
  print("   1PI2XIUId .bK.  :MQBQPXBiBRdB. i5.:7i.rQ :SP   SEr 5b7 E:.r7:.E: KEi Z.:77..g..X1r7:    UKI1Z    ")
  print("  :qD:    XKJ 2Ks:..Y.:qQDQ2:PQBQ  bji::rRi iqbqi7IM  2dL rdii:iUE  IZr LPii:iXK iULrr:r.  .IvUu    ")
  print("  r1J     7sU  ijU5u7  :BQK   BgBv  7j1Ju.  :u7:Iuj   L1i  :uYuu7   JU:  :uY1Jr  .vu::jJE   vrq     ")
  print("                                                                                 j7i  .7K   :7J     ")
  print("                                                                                 :ririrr   :7Y.     ")
  print("")
  }
